JTokenType

Enum JTokenType 

pub enum JTokenType {
Show 34 variants Whitespace, Newline, Comment, StringLiteral, NumberLiteral, Identifier, Equal, Dot, Colon, IsGlobal, IsLocal, Plus, Minus, Star, Percent, Dollar, Comma, Hash, Slash, Backslash, Pipe, Ampersand, Caret, Tilde, Less, Greater, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Eof, Error,
}
J token type

Variants



Whitespace

Whitespace



Newline

Newline



Comment

Comment



StringLiteral

String literal



NumberLiteral

Number literal



Identifier

Identifier



Equal

Equal (=)



Dot

Dot (.)



Colon

Colon (:)



IsGlobal

Global assignment (=:)



IsLocal

Local assignment (=.)



Plus

Plus (+)



Minus

Minus (-)



Star

Star (*)



Percent

Percent (%)



Dollar

Dollar ($)



Comma

Comma (,)



Hash

Hash (#)



Slash

Slash (/)



Backslash

Backslash ()



Pipe

Pipe (|)



Ampersand

Ampersand (&)



Caret

Caret (^)



Tilde

Tilde (~)



Less

Less (<)



Greater

Greater (>)



LeftParen

Left parenthesis (()



RightParen

Right parenthesis ())



LeftBracket

Left bracket ([)



RightBracket

Right bracket (])



LeftBrace

Left brace ({)



RightBrace

Right brace (})



Eof

End of file



Error

Error unit

Implementations

Source

impl JTokenType

pub fn is_keyword(&self) -> bool

Is keyword (J mostly uses primitives)

pub fn is_punctuation(&self) -> bool

Is punctuation

pub fn is_ignored(&self) -> bool

Is ignored token (whitespace or comment)